@@ -35,6 +35,7 @@ from chipwhisperer.common.utils import util
 from chipwhisperer.common.utils.util import dict_to_str, DelayedKeyboardInterrupt
 from collections import OrderedDict
 import time
+import numpy as np
 
 class OpenADC(ScopeTemplate, util.DisableNewAttr):
     """OpenADC scope object.
@@ -70,6 +71,7 @@ class OpenADC(ScopeTemplate, util.DisableNewAttr):
      *  :meth:`scope.dis <.OpenADC.dis>`
      *  :meth:`scope.arm <.OpenADC.arm>`
      *  :meth:`scope.get_last_trace <.OpenADC.get_last_trace>`
+     *  :meth:`scope.get_serial_ports <.OpenADC.get_serial_ports>`
 
     If you have a CW1200 ChipWhisperer Pro, you have access to some additional features:
 
@@ -113,9 +115,26 @@ class OpenADC(ScopeTemplate, util.DisableNewAttr):
     def sn(self):
         return self.scopetype.ser.snum
 
+    def reload_fpga(self, bitstream=None):
+        """(Re)loads a FPGA bitstream (even if already configured).
+
+        Will cause a reconnect event, all settings become default again.
+        If no bitstream specified default is used based on current
+        configuration settings.
+        """        
+        self.scopetype.reload_fpga(bitstream)
+
     def _getNAEUSB(self):
         return self.scopetype.dev._cwusb
 
+    def get_serial_ports(self):
+        """ Get the CDC serial ports associated with this scope
+
+        Returns:
+            A list of a dict with elements {'port', 'interface'}
+        """
+        return self._getNAEUSB().get_serial_ports()
+
     def default_setup(self):
         """Sets up sane capture defaults for this scope
 
@@ -127,6 +146,7 @@ class OpenADC(ScopeTemplate, util.DisableNewAttr):
          *  4*7.37MHz ADC clock
          *  tio1 = serial rx
          *  tio2 = serial tx
+         *  CDC settings change off
 
         .. versionadded:: 5.1
             Added default setup for OpenADC
@@ -142,6 +162,7 @@ class OpenADC(ScopeTemplate, util.DisableNewAttr):
         self.io.hs2 = "clkgen"
 
         self.clock.adc_src = "clkgen_x4"
+        self.io.cdc_settings = 0
 
         count = 0
         while not self.clock.clkgen_locked:            
@@ -221,7 +242,9 @@ class OpenADC(ScopeTemplate, util.DisableNewAttr):
         if self.scopetype is not None:
             self.scopetype.con(sn)
 
-            self.qtadc.sc.usbcon = self.scopetype.ser._usbdev
+            if hasattr(self.scopetype, "ser") and hasattr(self.scopetype.ser, "_usbdev"):
+                self.qtadc.sc.usbcon = self.scopetype.ser._usbdev
+            #self.qtadc.sc.usbcon = self.scopetype.ser._usbdev
 
             cwtype = self._getCWType()
             if cwtype != "":
@@ -293,20 +316,20 @@ class OpenADC(ScopeTemplate, util.DisableNewAttr):
         """
         if self.connectStatus is False:
             raise OSError("Scope is not connected. Connect it first...")
-        with DelayedKeyboardInterrupt():
-            try:
-                if self.advancedSettings:
-                    self.advancedSettings.armPreScope()
+        # with DelayedKeyboardInterrupt():
+        try:
+            if self.advancedSettings:
+                self.advancedSettings.armPreScope()
 
-                self.qtadc.arm()
+            self.qtadc.arm()
 
-                if self.advancedSettings:
-                    self.advancedSettings.armPostScope()
+            if self.advancedSettings:
+                self.advancedSettings.armPostScope()
 
-                self.qtadc.startCaptureThread()
-            except Exception:
-                self.dis()
-                raise
+            self.qtadc.startCaptureThread()
+        except Exception:
+            self.dis()
+            raise
 
     def capture(self):
         """Captures trace. Scope must be armed before capturing.
@@ -318,11 +341,11 @@ class OpenADC(ScopeTemplate, util.DisableNewAttr):
            IOError: Unknown failure.
         """
         # need adc offset, adc_freq, samples cached
-        with DelayedKeyboardInterrupt():
-            if not self.adc.stream_mode:
-                return self.qtadc.capture(self.adc.offset, self.clock.adc_freq, self.adc.samples)
-            else:
-                return self.qtadc.capture(None)
+        # with DelayedKeyboardInterrupt():
+        if not self.adc.stream_mode:
+            return self.qtadc.capture(self.adc.offset, self.clock.adc_freq, self.adc.samples)
+        else:
+            return self.qtadc.capture(None)
 
     def get_last_trace(self):
         """Return the last trace captured with this scope.
@@ -330,10 +353,48 @@ class OpenADC(ScopeTemplate, util.DisableNewAttr):
         Returns:
            Numpy array of the last capture trace.
         """
-        return self.qtadc.datapoints
+        return self.qtadc.datapoints    
 
     getLastTrace = util.camel_case_deprecated(get_last_trace)
 
+    def capture_segmented(self):
+        """Captures trace in segment mode, returns as many segments as buffer holds.
+
+        Timeouts not handled yet properly (function will lock). Be sure you are generating
+        enough triggers for segmented mode.
+
+        Returns:
+           True if capture timed out, false if it didn't.
+
+        Raises:
+           IOError: Unknown failure.
+        """
+
+        if self.adc.fifo_fill_mode != "segment":
+            raise IOError("ADC is not in 'segment' mode - aborting.")
+
+        with DelayedKeyboardInterrupt():
+            max_fifo_size = self.adc.oa.hwMaxSamples
+            #self.adc.offset should maybe be ignored - passing for now but untested
+            timeout = self.qtadc.sc.capture(self.adc.offset, self.clock.adc_freq, max_fifo_size)
+            timeout2 = self.qtadc.read(max_fifo_size-256)
+
+            return timeout or timeout2 
+
+    def get_last_trace_segmented(self):
+        """Return last trace assuming it was captued with segmented mode.
+
+        NOTE: The length of each returned trace is 1 less sample than requested.
+
+        Returns:
+            2-D numpy array of the last captured traces.
+        """
+
+        seg_len = self.adc.samples-1
+        num_seg = int(len(self.qtadc.datapoints) / seg_len)
+
+        return np.reshape(self.qtadc.datapoints[:num_seg*seg_len], (num_seg, seg_len))
+
     def _dict_repr(self):
         dict = OrderedDict()
         dict['sn'] = self.sn
