@@ -336,7 +336,7 @@ class TriggerSettings(util.DisableNewAttr):
         self._is_pro = False
         self._cached_samples = None
         self._cached_offset = None
-
+        self._is_sakura_g = None
 
         self.disable_newattr()
 
@@ -350,6 +350,7 @@ class TriggerSettings(util.DisableNewAttr):
         dict['samples']    = self.samples
         dict['decimate']   = self.decimate
         dict['trig_count'] = self.trig_count
+        dict['fifo_fill_mode'] = self.fifo_fill_mode
         if self._is_pro:
             dict['stream_mode'] = self.stream_mode
 
@@ -442,6 +443,18 @@ class TriggerSettings(util.DisableNewAttr):
 
     @samples.setter
     def samples(self, samples):
+        if self._is_sakura_g:
+            diff = (12 - (samples % 12)) % 12
+            samples += diff
+            if diff > 0:
+                logging.warning("Sakura G samples must be divisible by 12, rounding up to {}...".format(samples))
+
+        if self._get_fifo_fill_mode() == "segment":
+            diff = (3 - (samples - 1) % 3)
+            samples += diff
+            if diff > 0:
+                logging.warning("segment mode requires (samples-1) divisible by 3, rounding up to {}...".format(samples))
+
         self._cached_samples = samples
         self._set_num_samples(samples)
 
@@ -515,6 +528,9 @@ class TriggerSettings(util.DisableNewAttr):
     def basic_mode(self):
         """The type of event to use as a trigger.
 
+        Only applies to the ADC capture - the glitch module
+        is always a rising edge trigger.
+
         There are four possible types of trigger events:
          * "low": triggers when line is low (logic 0)
          * "high": triggers when line is high (logic 1)
@@ -568,6 +584,86 @@ class TriggerSettings(util.DisableNewAttr):
         """
         return self._get_duration()
 
+    @property
+    def fifo_fill_mode(self):
+        """The ADC buffer fill strategy - allows segmented usage.
+
+        .. warning:: THIS REQUIRES NEW FPGA BITSTREAM - NOT YET IN THE PYTHON.
+
+        Only the 'Normal' mode is well supported, the other modes can
+        be used carefully.
+
+        There are four possible modes:
+         * "normal": Trigger line & logic work as expected.
+         * "enable": Capture starts with rising edge, but writing samples
+                     is enabled by active-high state of trigger line.
+         * "segment": Capture starts with rising edge, and writes `trigger.samples`
+                     to buffer on each rising edge, stopping when the buffer
+                     is full. For this to work adc.samples must be a multiple
+                     of 3 (will be enforced by API).
+
+        .. warning:: The "enable" and "segment" modes requires you to fill
+                    the **full buffer** (~25K on CW-Lite, ~100K on CW-Pro).
+                    This requires you to ensure the physical trigger line will
+                    be high (enable mode) or toggle (segment mode) enough. The
+                    ChipWhisperer hardware will currently stall until the
+                    internal buffer is full, and future commands will fail.
+
+        .. warning:: adc.basic_mode must be set to "rising_edge" if a fill_mode other than
+                    "normal" is used. Bad things happen if not.
+
+        :Getter: Return the current fifo fill mode (one of the 3 above strings)
+
+        :Setter: Set the fifo fill mode
+
+        Raises:
+           ValueError: if value is not one of the allowed strings
+        """
+
+        return self._get_fifo_fill_mode()
+
+    @fifo_fill_mode.setter
+    def fifo_fill_mode(self, mode):
+        known_modes = ["normal", "enable", "segment"]
+        if mode not in known_modes:
+            raise ValueError("Invalid fill mode %s. Valid modes: %s" % (mode, known_modes), mode)
+
+        self._set_fifo_fill_mode(mode)
+
+        # Segment mode requires samples have an odd divisability to work
+        if mode == "segment":
+            self.samples = self.samples
+
+    def _get_fifo_fill_mode(self):
+        result = self.oa.sendMessage(CODE_READ, ADDR_ADVCLK, maxResp=4)
+        mode = result[3] & 0x30
+
+        if mode == 0x00:
+            return "normal"
+
+        if mode == 0x10:
+            return "enable"
+
+        if mode == 0x20:
+            return "segment"
+
+        return "????"
+
+    def _set_fifo_fill_mode(self, mode):
+        if mode == "normal":
+            mask = 0
+        elif mode == "enable":
+            mask = 1
+        elif mode == "segment":
+            mask = 2
+        else:
+            raise ValueError("Invalid option for fifo mode: {}".format(mask))
+
+        result = self.oa.sendMessage(CODE_READ, ADDR_ADVCLK, maxResp=4)
+        result[3] &= ~(0x30)
+        result[3] |= mask << 4
+        self.oa.sendMessage(CODE_WRITE, ADDR_ADVCLK, result, readMask= [0x3f, 0xff, 0xff, 0xfd])
+
     def _set_stream_mode(self, enabled):
         self._stream_mode = enabled
 
@@ -1608,7 +1704,7 @@ class OpenADCInterface(object):
             message = message + pba
 
             # ## Send out serial port
-            self.serial.write(str(message))
+            self.serial.write(message)
 
             # for b in message: print "%02x "%b,
             # print ""
@@ -1685,7 +1781,7 @@ class OpenADCInterface(object):
     def triggerNow(self):
         initial = self.settings()
         self.setSettings(initial | SETTINGS_TRIG_NOW)
-        time.sleep(0.001)
+        time.sleep(0.05)
         self.setSettings(initial & ~SETTINGS_TRIG_NOW)
 
     def getStatus(self):
@@ -1861,7 +1957,7 @@ class OpenADCInterface(object):
 
                 # If we've timed out, don't wait any longer for a trigger
                 if (diff.total_seconds() > self._timeout):
-                    logging.warning('Timeout in OpenADC capture(), trigger FORCED')
+                    logging.warning('Timeout in OpenADC capture(), no trigger seen! Trigger forced, data is invalid. Status: %02x'%status)
                     timeout = True
                     self.triggerNow()
                     break
@@ -1895,12 +1991,15 @@ class OpenADCInterface(object):
 
                 # If we've timed out, don't wait any longer for a trigger
                 if (diff.total_seconds() > self._timeout):
-                    logging.warning('Timeout in OpenADC capture(), trigger FORCED')
+                    logging.warning('Timeout in OpenADC capture(), no trigger seen! Trigger forced, data is invalid. Status: %02x'%status)
                     timeout = True
                     self.triggerNow()
 
+                    #Once in timeout mode we can't rely on STATUS_ARM_MASK anymore - just wait for FIFO to fill up
+                    if (status & STATUS_FIFO_MASK) == 0:
+                        break
+
                 # Give the UI a chance to update (does nothing if not using UI)
-                # util.updateUI()
 
             #time.sleep(0.005)
             #time.sleep(sleeptime*10)
@@ -2020,6 +2119,7 @@ class OpenADCInterface(object):
                 # print "bytes = %d"%self.getBytesInFifo()
 
                 bytesToRead = self.getBytesInFifo()
+                #print(bytesToRead)
 
                 # print bytesToRead
 
@@ -2035,6 +2135,7 @@ class OpenADCInterface(object):
 
                 # +1 for sync byte
                 data = self.sendMessage(CODE_READ, ADDR_ADCDATA, None, False, bytesToRead + 1)  # BytesPerPackage)
+                #print(data)
 
                 # for p in data:
                 #       print "%x "%p,
@@ -2052,6 +2153,8 @@ class OpenADCInterface(object):
             # for point in datapoints:
             #       print "%3x"%(int((point+0.5)*1024))
 
+            if datapoints is None:
+                return []
             if len(datapoints) > NumberPoints:
                 datapoints = datapoints[0:NumberPoints]
 
@@ -2064,6 +2167,7 @@ class OpenADCInterface(object):
     def processData(self, data, pad=float('NaN'), debug=False):
         if data[0] != 0xAC:
             logging.warning('Unexpected sync byte in processData(): 0x%x' % data[0])
+            #print(data)
             return None
 
         orig_data = copy.copy(data)
