@@ -14,3 +14,7 @@ Scopes:
 """
 from chipwhisperer.capture.scopes.OpenADC import OpenADC
 from .cwnano import CWNano
+try:
+   from .sakura_g import SakuraG
+except:
+   pass
\ No newline at end of file
