@@ -117,6 +117,8 @@ class GPIOSettings(util.DisableNewAttr):
 
         dict['tio_states'] = self.tio_states
 
+        dict['cdc_settings'] = self.cdc_settings
+
         return dict
 
     @property
@@ -189,6 +191,32 @@ class GPIOSettings(util.DisableNewAttr):
         except KeyError:
             return "?"
 
+    @property
+    def cdc_settings(self):
+        """Check or set whether USART settings can be changed via the USB CDC connection
+
+        i.e. whether you can change USART settings (baud rate, 8n1) via a serial client like PuTTY
+
+        :getter: An array of length two for two possible CDC serial ports (though only one is used)
+
+        :setter: Can set either via an integer (which sets both ports) or an array of length 2 (which sets each port)
+
+        Returns None if using firmware before the CDC port was added
+        """
+        rawver = self.cwe.oa.serial.readFwVersion()
+        ver = '{}.{}'.format(rawver[0], rawver[1])
+        if ver < '0.30':
+            return None
+        return self.cwe.oa.serial.get_cdc_settings()
+
+    @cdc_settings.setter
+    def cdc_settings(self, port):
+        rawver = self.cwe.oa.serial.readFwVersion()
+        ver = '{}.{}'.format(rawver[0], rawver[1])
+        if ver < '0.30':
+            return None
+        return self.cwe.oa.serial.set_cdc_settings(port)
+
     @property
     def tio1(self):
         """The function of the Target IO1 pin.
@@ -721,6 +749,7 @@ class ProTrigger(TriggerSettings):
     def _dict_repr(self):
         dict = super()._dict_repr()
         dict['module'] = self.module
+        dict['aux_out'] = self.aux_out
         return dict
 
     @property
@@ -733,33 +762,16 @@ class ProTrigger(TriggerSettings):
 
         Available trigger modules:
          * 'basic': Trigger on a logic level or edge
-         * 'SAD':   Trigger from SAD module
-         * 'DECODEIO': Trigger from decode_IO module
-
+         * 'SAD':   Trigger from SAD module (CWPro only)
+         * 'DECODEIO': Trigger from decode_IO module (CWPro only)
 
         :Getter: Return the active trigger module
 
         :Setter: Sets the active trigger module
 
-        .. todo:: add support for CW1200 serial data trigger
-        .. todo:: Fix getter so that we don't have to store the module anymore
-
         Raises:
             ValueError: module isn't one of the available strings
         """
-        '''
-        resp = self.cwe.oa.sendMessage(CODE_READ, ADDR_TRIGMOD,
-                                       Validate=False, maxResp=1)
-        module = resp[0] & 0xF8
-        if module == self.cwe.MODULE_BASIC:
-            return "basic"
-        elif module == self.cwe.MODULE_SADPATTERN:
-            return "SAD"
-        elif module == self.cwe.MODULE_DECODEIO:
-            return "DECODEIO"
-        else:
-            return "Unknown"
-        '''
         return self.last_module
 
     @module.setter
@@ -781,6 +793,28 @@ class ProTrigger(TriggerSettings):
                                        resp)
         self.last_module = mode
 
+    @property
+    def aux_out(self):
+        """Controls AUX out on the CWPro
+
+        CWPro only
+
+        :Getter: Returns True if yes, False if no
+
+        :Setter: Set True to enable aux_out, False to disable
+        """
+        resp = self.cwe.oa.sendMessage(CODE_READ, ADDR_TRIGMOD, Validate=False, maxResp=1)
+        return bool(resp[0] & 0x08)
+
+    @aux_out.setter
+    def aux_out(self, enabled):
+        resp = self.cwe.oa.sendMessage(CODE_READ, ADDR_TRIGMOD, Validate=False, maxResp=1)
+        resp[0] &= 0xE7
+        if enabled:
+            resp[0] |= 0x08
+        self.cwe.oa.sendMessage(CODE_WRITE, ADDR_TRIGMOD, resp)
+
+
 
 
 class SADTrigger(util.DisableNewAttr):
