@@ -28,7 +28,6 @@ import time
 import random
 from datetime import datetime
 import os.path
-import pkg_resources
 import re
 import io
 from ._base import TargetTemplate
@@ -107,6 +106,7 @@ class CW305(TargetTemplate):
     BATCHRUN_RANDOM_PT = 0x4
 
     def __init__(self):
+        import chipwhisperer as cw
         TargetTemplate.__init__(self)
         self._naeusb = NAEUSB()
         self.pll = PLLCDCE906(self._naeusb, ref_freq = 12.0E6)
@@ -117,7 +117,7 @@ class CW305(TargetTemplate):
 
         self._woffset_sam3U = 0x000
         self.default_verilog_defines = 'cw305_defines.v'
-        self.default_verilog_defines_full_path = '../../hardware/victims/cw305_artixtarget/fpga/common/' + self.default_verilog_defines
+        self.default_verilog_defines_full_path = os.path.dirname(cw.__file__) +  '/../../hardware/victims/cw305_artixtarget/fpga/common/' + self.default_verilog_defines
         self.registers = 12 # number of registers we expect to find
         self.bytecount_size = 7 # pBYTECNT_SIZE in Verilog
 
@@ -232,7 +232,7 @@ class CW305(TargetTemplate):
 
         # print "vccint = " + str(vccint)
 
-        if (vccint < 0.6) or (vccint > 1.15):
+        if (vccint < 0.6) or (vccint > 1.1):
             raise ValueError("VCC-Int out of range 0.6V-1.1V")
 
         # Convert to mV
@@ -357,6 +357,9 @@ class CW305(TargetTemplate):
         #self.newInputData.emit(util.list2hexstr(data))
         return data
 
+    def _getCWType(self):
+        return 'cw305'
+
     @property
     def latest_fw(self):
         cw_type = self._getCWType()
@@ -1300,7 +1303,7 @@ class FPGAIO:
             
             tx = data[i:dataend]
             rx = self.spi1_tx_rx(tx)
-            resp.append(rx)
+            resp.extend(rx)
 
         self.spi1_set_cs_pin(True)
 
