@@ -10,12 +10,11 @@ Targets:
 """
 from .SimpleSerial import SimpleSerial
 from .CW305 import CW305
-from .SimpleSerial2 import SimpleSerial2
+from .SimpleSerial2 import SimpleSerial2, SimpleSerial2_CDC
 from .CW305_ECC import CW305_ECC
 
 try:
-    from .SAKURAG import SakuraG #needs ftdi module
-    from .SASEBOGII import SaseboGII
+    from .sakura_g import SakuraG #needs ftdi module
 except ImportError:
     pass
 
