@@ -488,7 +488,7 @@ class Project(Parameterized):
 
         if file_type == 'zip':
             file_path = os.path.abspath(file_path)
-            with zipfile.ZipFile(file_path, 'w') as zip:
+            with zipfile.ZipFile(file_path, 'w', zipfile.ZIP_DEFLATED) as zip:
                 common_path = os.path.commonpath(file_paths)
                 for file in file_paths:
                     relative_path = os.path.relpath(file, common_path)
@@ -883,4 +883,4 @@ class IndividualIterable:
         len_trace = len(self.getter(0))
         arr = np.zeros((num_traces, len_trace), dtype=dtype)
         arr[:,:] = np.array([self.getter(i) for i in range(num_traces)])[:,:]
-        return arr
\ No newline at end of file
+        return arr
