@@ -362,14 +362,6 @@ class NAEUSB_Backend(NAEUSB_Serializer_base):
             else:
                 #User did not help us out - throw it in their face
                 raise Warning("Found multiple potential USB devices. Please specify device to use. Possible S/Ns:\n" + snlist)
-        try:
-            try:
-                dev.set_configuration(0)
-            except:
-                pass #test
-            dev.set_configuration()
-        except ValueError:
-            raise OSError("NAEUSB: Could not configure USB device")
 
         # Get serial number
         try:
@@ -503,7 +495,15 @@ class NAEUSB_Backend(NAEUSB_Serializer_base):
         # ADDR/LEN written LSB first
         pload = packuint32(dlen)
         pload.extend(packuint32(addr))
-        self.sendCtrl(cmd, data=pload)
+        try:
+            self.sendCtrl(cmd, data=pload)
+        except usb.USBError as e:
+            if "Pipe error" in str(e):
+                logging.warning("Attempting pipe error fix - typically safe to ignore")
+                self.sendCtrl(0x22, 0x11)
+                self.sendCtrl(cmd, data=pload)
+            else:
+                raise
 
         # Get data
         if cmd == self.CMD_READMEM_BULK:
@@ -566,7 +566,6 @@ class NAEUSB_Backend(NAEUSB_Serializer_base):
         
         return data
 
-
     def cmdWriteBulk(self, data):
         """
         Write data directly to the bulk endpoint.
@@ -576,7 +575,6 @@ class NAEUSB_Backend(NAEUSB_Serializer_base):
 
         self.usbdev().write(self.wep, data, timeout=self._timeout)
 
-
     def flushInput(self):
         """Dump all the crap left over"""
         try:
@@ -595,6 +593,7 @@ class NAEUSB(object):
     """
 
     CMD_FW_VERSION = 0x17
+    CMD_CDC_SETTINGS_EN = 0x31
 
     CMD_READMEM_BULK = 0x10
     CMD_WRITEMEM_BULK = 0x11
@@ -615,6 +614,29 @@ class NAEUSB(object):
     def get_possible_devices(self, idProduct):
         return self.usbseralizer.get_possible_devices(idProduct)
 
+    def get_cdc_settings(self):
+        return self.usbtx.readCtrl(self.CMD_CDC_SETTINGS_EN, dlen=2)
+
+    def set_cdc_settings(self, port=[1, 1]):
+        if isinstance(port, int):
+            port = [port, port]
+        self.usbtx.sendCtrl(self.CMD_CDC_SETTINGS_EN, (port[0]) | (port[1] << 1))
+
+
+    def get_serial_ports(self):
+        """May have multiple com ports associated with one device, so returns a list of port + interface
+        """
+        if not self.usbtx._usbdev:
+            raise OSError("Connect to device before calling this")
+        import serial.tools.list_ports
+        if serial.__version__ < '3.5':
+            raise OSError("Pyserial >= 3.5 (found {}) required for this method".format(serial.__version__))
+        devices = []
+        for port in serial.tools.list_ports.comports():
+            if port.serial_number == self.usbtx._usbdev.serial_number.upper():
+                devices.append({"port": port.device, "interface": port.location.split('.')[-1]})
+        return devices
+
     def con(self, idProduct=[0xACE2], connect_to_first=False, serial_number=None):
         """
         Connect to device using default VID/PID
@@ -680,6 +702,13 @@ class NAEUSB(object):
         self.usbseralizer.close(self.snum)
         self.snum = None
 
+    def readCDCSettings(self):
+        try:
+            data = self.readCtrl(self.CMD_FW_VERSION, dlen=3)
+            return data
+        except usb.USBError:
+            return [0, 0]
+
     def readFwVersion(self):
         try:
             data = self.readCtrl(self.CMD_FW_VERSION, dlen=3)
@@ -823,6 +852,11 @@ class NAEUSB(object):
         if forreal:
             self.sendCtrl(0x22, 3)
 
+    def reset(self):
+        """ Reset the SAM3U. Requires firmware 0.30 or later
+        """
+        self.sendCtrl(0x22, 0x10)
+
     def read(self, dlen, timeout=2000):
         self.usbserializer.read(dlen, timeout)
 
